# coding: utf-8
import pprint
import six
from enum import Enum



class AbstractSpaceUpdate:

    swagger_types = {
    
        'last_modified_date': 'datetime',
        'name': 'str',
        'postal_address': 'SpaceAddressCreate',
        'primary_currency': 'str',
        'request_limit': 'int',
        'state': 'CreationEntityState',
        'technical_contact_addresses': 'list[str]',
        'time_zone': 'str',
    }

    attribute_map = {
        'last_modified_date': 'lastModifiedDate','name': 'name','postal_address': 'postalAddress','primary_currency': 'primaryCurrency','request_limit': 'requestLimit','state': 'state','technical_contact_addresses': 'technicalContactAddresses','time_zone': 'timeZone',
    }

    
    _last_modified_date = None
    _name = None
    _postal_address = None
    _primary_currency = None
    _request_limit = None
    _state = None
    _technical_contact_addresses = None
    _time_zone = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.last_modified_date = kwargs.get('last_modified_date', None)
        self.name = kwargs.get('name', None)
        self.postal_address = kwargs.get('postal_address', None)
        self.primary_currency = kwargs.get('primary_currency', None)
        self.request_limit = kwargs.get('request_limit', None)
        self.state = kwargs.get('state', None)
        self.technical_contact_addresses = kwargs.get('technical_contact_addresses', None)
        self.time_zone = kwargs.get('time_zone', None)
        

    
    @property
    def last_modified_date(self):
        """Gets the last_modified_date of this AbstractSpaceUpdate.

            The date and time when the object was last modified.

        :return: The last_modified_date of this AbstractSpaceUpdate.
        :rtype: datetime
        """
        return self._last_modified_date

    @last_modified_date.setter
    def last_modified_date(self, last_modified_date):
        """Sets the last_modified_date of this AbstractSpaceUpdate.

            The date and time when the object was last modified.

        :param last_modified_date: The last_modified_date of this AbstractSpaceUpdate.
        :type: datetime
        """

        self._last_modified_date = last_modified_date
    
    @property
    def name(self):
        """Gets the name of this AbstractSpaceUpdate.

            The name used to identify the space.

        :return: The name of this AbstractSpaceUpdate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AbstractSpaceUpdate.

            The name used to identify the space.

        :param name: The name of this AbstractSpaceUpdate.
        :type: str
        """
        if name is not None and len(name) > 200:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `200`")
        if name is not None and len(name) < 3:
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `3`")

        self._name = name
    
    @property
    def postal_address(self):
        """Gets the postal_address of this AbstractSpaceUpdate.

            The address that is used in communication with clients for example in emails, documents, etc.

        :return: The postal_address of this AbstractSpaceUpdate.
        :rtype: SpaceAddressCreate
        """
        return self._postal_address

    @postal_address.setter
    def postal_address(self, postal_address):
        """Sets the postal_address of this AbstractSpaceUpdate.

            The address that is used in communication with clients for example in emails, documents, etc.

        :param postal_address: The postal_address of this AbstractSpaceUpdate.
        :type: SpaceAddressCreate
        """

        self._postal_address = postal_address
    
    @property
    def primary_currency(self):
        """Gets the primary_currency of this AbstractSpaceUpdate.

            The currency that is used to display aggregated amounts in the space.

        :return: The primary_currency of this AbstractSpaceUpdate.
        :rtype: str
        """
        return self._primary_currency

    @primary_currency.setter
    def primary_currency(self, primary_currency):
        """Sets the primary_currency of this AbstractSpaceUpdate.

            The currency that is used to display aggregated amounts in the space.

        :param primary_currency: The primary_currency of this AbstractSpaceUpdate.
        :type: str
        """

        self._primary_currency = primary_currency
    
    @property
    def request_limit(self):
        """Gets the request_limit of this AbstractSpaceUpdate.

            The maximum number of API requests that are accepted within two minutes. This limit can only be changed with special privileges.

        :return: The request_limit of this AbstractSpaceUpdate.
        :rtype: int
        """
        return self._request_limit

    @request_limit.setter
    def request_limit(self, request_limit):
        """Sets the request_limit of this AbstractSpaceUpdate.

            The maximum number of API requests that are accepted within two minutes. This limit can only be changed with special privileges.

        :param request_limit: The request_limit of this AbstractSpaceUpdate.
        :type: int
        """

        self._request_limit = request_limit
    
    @property
    def state(self):
        """Gets the state of this AbstractSpaceUpdate.

            The object's current state.

        :return: The state of this AbstractSpaceUpdate.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this AbstractSpaceUpdate.

            The object's current state.

        :param state: The state of this AbstractSpaceUpdate.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def technical_contact_addresses(self):
        """Gets the technical_contact_addresses of this AbstractSpaceUpdate.

            The email address that will receive messages about technical issues and errors that occur in the space.

        :return: The technical_contact_addresses of this AbstractSpaceUpdate.
        :rtype: list[str]
        """
        return self._technical_contact_addresses

    @technical_contact_addresses.setter
    def technical_contact_addresses(self, technical_contact_addresses):
        """Sets the technical_contact_addresses of this AbstractSpaceUpdate.

            The email address that will receive messages about technical issues and errors that occur in the space.

        :param technical_contact_addresses: The technical_contact_addresses of this AbstractSpaceUpdate.
        :type: list[str]
        """

        self._technical_contact_addresses = technical_contact_addresses
    
    @property
    def time_zone(self):
        """Gets the time_zone of this AbstractSpaceUpdate.

            The time zone that is used to schedule and run background processes. This does not affect the formatting of dates in the user interface.

        :return: The time_zone of this AbstractSpaceUpdate.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this AbstractSpaceUpdate.

            The time zone that is used to schedule and run background processes. This does not affect the formatting of dates in the user interface.

        :param time_zone: The time_zone of this AbstractSpaceUpdate.
        :type: str
        """

        self._time_zone = time_zone
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AbstractSpaceUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AbstractSpaceUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class ShopifyIntegration:

    swagger_types = {
    
        'additional_line_item_data': 'list[ShopifyAdditionalLineItemData]',
        'allow_invoice_download': 'bool',
        'allowed_payment_method_configurations': 'list[PaymentMethodConfiguration]',
        'currency': 'str',
        'id': 'int',
        'integrated_payment_form_enabled': 'bool',
        'language': 'str',
        'login_name': 'str',
        'name': 'str',
        'payment_app_version': 'ShopifyIntegrationPaymentAppVersion',
        'payment_installed': 'bool',
        'payment_proxy_path': 'str',
        'planned_purge_date': 'datetime',
        'replace_payment_method_image': 'bool',
        'shop_name': 'str',
        'show_payment_information': 'bool',
        'show_subscription_information': 'bool',
        'space_id': 'int',
        'space_view_id': 'int',
        'state': 'CreationEntityState',
        'subscription_app_version': 'ShopifyIntegrationSubscriptionAppVersion',
        'subscription_installed': 'bool',
        'subscription_proxy_path': 'str',
        'version': 'int',
    }

    attribute_map = {
        'additional_line_item_data': 'additionalLineItemData','allow_invoice_download': 'allowInvoiceDownload','allowed_payment_method_configurations': 'allowedPaymentMethodConfigurations','currency': 'currency','id': 'id','integrated_payment_form_enabled': 'integratedPaymentFormEnabled','language': 'language','login_name': 'loginName','name': 'name','payment_app_version': 'paymentAppVersion','payment_installed': 'paymentInstalled','payment_proxy_path': 'paymentProxyPath','planned_purge_date': 'plannedPurgeDate','replace_payment_method_image': 'replacePaymentMethodImage','shop_name': 'shopName','show_payment_information': 'showPaymentInformation','show_subscription_information': 'showSubscriptionInformation','space_id': 'spaceId','space_view_id': 'spaceViewId','state': 'state','subscription_app_version': 'subscriptionAppVersion','subscription_installed': 'subscriptionInstalled','subscription_proxy_path': 'subscriptionProxyPath','version': 'version',
    }

    
    _additional_line_item_data = None
    _allow_invoice_download = None
    _allowed_payment_method_configurations = None
    _currency = None
    _id = None
    _integrated_payment_form_enabled = None
    _language = None
    _login_name = None
    _name = None
    _payment_app_version = None
    _payment_installed = None
    _payment_proxy_path = None
    _planned_purge_date = None
    _replace_payment_method_image = None
    _shop_name = None
    _show_payment_information = None
    _show_subscription_information = None
    _space_id = None
    _space_view_id = None
    _state = None
    _subscription_app_version = None
    _subscription_installed = None
    _subscription_proxy_path = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.additional_line_item_data = kwargs.get('additional_line_item_data', None)
        self.allow_invoice_download = kwargs.get('allow_invoice_download', None)
        self.allowed_payment_method_configurations = kwargs.get('allowed_payment_method_configurations', None)
        self.currency = kwargs.get('currency', None)
        self.id = kwargs.get('id', None)
        self.integrated_payment_form_enabled = kwargs.get('integrated_payment_form_enabled', None)
        self.language = kwargs.get('language', None)
        self.login_name = kwargs.get('login_name', None)
        self.name = kwargs.get('name', None)
        self.payment_app_version = kwargs.get('payment_app_version', None)
        self.payment_installed = kwargs.get('payment_installed', None)
        self.payment_proxy_path = kwargs.get('payment_proxy_path', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.replace_payment_method_image = kwargs.get('replace_payment_method_image', None)
        self.shop_name = kwargs.get('shop_name', None)
        self.show_payment_information = kwargs.get('show_payment_information', None)
        self.show_subscription_information = kwargs.get('show_subscription_information', None)
        self.space_id = kwargs.get('space_id', None)
        self.space_view_id = kwargs.get('space_view_id', None)
        self.state = kwargs.get('state', None)
        self.subscription_app_version = kwargs.get('subscription_app_version', None)
        self.subscription_installed = kwargs.get('subscription_installed', None)
        self.subscription_proxy_path = kwargs.get('subscription_proxy_path', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def additional_line_item_data(self):
        """Gets the additional_line_item_data of this ShopifyIntegration.

            

        :return: The additional_line_item_data of this ShopifyIntegration.
        :rtype: list[ShopifyAdditionalLineItemData]
        """
        return self._additional_line_item_data

    @additional_line_item_data.setter
    def additional_line_item_data(self, additional_line_item_data):
        """Sets the additional_line_item_data of this ShopifyIntegration.

            

        :param additional_line_item_data: The additional_line_item_data of this ShopifyIntegration.
        :type: list[ShopifyAdditionalLineItemData]
        """

        self._additional_line_item_data = additional_line_item_data
    
    @property
    def allow_invoice_download(self):
        """Gets the allow_invoice_download of this ShopifyIntegration.

            

        :return: The allow_invoice_download of this ShopifyIntegration.
        :rtype: bool
        """
        return self._allow_invoice_download

    @allow_invoice_download.setter
    def allow_invoice_download(self, allow_invoice_download):
        """Sets the allow_invoice_download of this ShopifyIntegration.

            

        :param allow_invoice_download: The allow_invoice_download of this ShopifyIntegration.
        :type: bool
        """

        self._allow_invoice_download = allow_invoice_download
    
    @property
    def allowed_payment_method_configurations(self):
        """Gets the allowed_payment_method_configurations of this ShopifyIntegration.

            

        :return: The allowed_payment_method_configurations of this ShopifyIntegration.
        :rtype: list[PaymentMethodConfiguration]
        """
        return self._allowed_payment_method_configurations

    @allowed_payment_method_configurations.setter
    def allowed_payment_method_configurations(self, allowed_payment_method_configurations):
        """Sets the allowed_payment_method_configurations of this ShopifyIntegration.

            

        :param allowed_payment_method_configurations: The allowed_payment_method_configurations of this ShopifyIntegration.
        :type: list[PaymentMethodConfiguration]
        """

        self._allowed_payment_method_configurations = allowed_payment_method_configurations
    
    @property
    def currency(self):
        """Gets the currency of this ShopifyIntegration.

            

        :return: The currency of this ShopifyIntegration.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this ShopifyIntegration.

            

        :param currency: The currency of this ShopifyIntegration.
        :type: str
        """

        self._currency = currency
    
    @property
    def id(self):
        """Gets the id of this ShopifyIntegration.

            A unique identifier for the object.

        :return: The id of this ShopifyIntegration.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ShopifyIntegration.

            A unique identifier for the object.

        :param id: The id of this ShopifyIntegration.
        :type: int
        """

        self._id = id
    
    @property
    def integrated_payment_form_enabled(self):
        """Gets the integrated_payment_form_enabled of this ShopifyIntegration.

            Enabling the integrated payment form will embed the payment form in the Shopify shop. The app needs to be installed for this to be possible.

        :return: The integrated_payment_form_enabled of this ShopifyIntegration.
        :rtype: bool
        """
        return self._integrated_payment_form_enabled

    @integrated_payment_form_enabled.setter
    def integrated_payment_form_enabled(self, integrated_payment_form_enabled):
        """Sets the integrated_payment_form_enabled of this ShopifyIntegration.

            Enabling the integrated payment form will embed the payment form in the Shopify shop. The app needs to be installed for this to be possible.

        :param integrated_payment_form_enabled: The integrated_payment_form_enabled of this ShopifyIntegration.
        :type: bool
        """

        self._integrated_payment_form_enabled = integrated_payment_form_enabled
    
    @property
    def language(self):
        """Gets the language of this ShopifyIntegration.

            The checkout language forces a specific language in the checkout. Without a checkout language the browser setting of the buyer is used to determine the language.

        :return: The language of this ShopifyIntegration.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this ShopifyIntegration.

            The checkout language forces a specific language in the checkout. Without a checkout language the browser setting of the buyer is used to determine the language.

        :param language: The language of this ShopifyIntegration.
        :type: str
        """

        self._language = language
    
    @property
    def login_name(self):
        """Gets the login_name of this ShopifyIntegration.

            The login name is used to link a specific Shopify payment gateway to this integration.This login name is to be filled into the appropriate field in the shops payment gateway configuration.

        :return: The login_name of this ShopifyIntegration.
        :rtype: str
        """
        return self._login_name

    @login_name.setter
    def login_name(self, login_name):
        """Sets the login_name of this ShopifyIntegration.

            The login name is used to link a specific Shopify payment gateway to this integration.This login name is to be filled into the appropriate field in the shops payment gateway configuration.

        :param login_name: The login_name of this ShopifyIntegration.
        :type: str
        """
        if login_name is not None and len(login_name) > 100:
            raise ValueError("Invalid value for `login_name`, length must be less than or equal to `100`")

        self._login_name = login_name
    
    @property
    def name(self):
        """Gets the name of this ShopifyIntegration.

            The integration name is used internally to identify a specific integration.For example the name is used withinsearch fields and hence it should be distinct and descriptive.

        :return: The name of this ShopifyIntegration.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ShopifyIntegration.

            The integration name is used internally to identify a specific integration.For example the name is used withinsearch fields and hence it should be distinct and descriptive.

        :param name: The name of this ShopifyIntegration.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def payment_app_version(self):
        """Gets the payment_app_version of this ShopifyIntegration.

            

        :return: The payment_app_version of this ShopifyIntegration.
        :rtype: ShopifyIntegrationPaymentAppVersion
        """
        return self._payment_app_version

    @payment_app_version.setter
    def payment_app_version(self, payment_app_version):
        """Sets the payment_app_version of this ShopifyIntegration.

            

        :param payment_app_version: The payment_app_version of this ShopifyIntegration.
        :type: ShopifyIntegrationPaymentAppVersion
        """

        self._payment_app_version = payment_app_version
    
    @property
    def payment_installed(self):
        """Gets the payment_installed of this ShopifyIntegration.

            

        :return: The payment_installed of this ShopifyIntegration.
        :rtype: bool
        """
        return self._payment_installed

    @payment_installed.setter
    def payment_installed(self, payment_installed):
        """Sets the payment_installed of this ShopifyIntegration.

            

        :param payment_installed: The payment_installed of this ShopifyIntegration.
        :type: bool
        """

        self._payment_installed = payment_installed
    
    @property
    def payment_proxy_path(self):
        """Gets the payment_proxy_path of this ShopifyIntegration.

            Define the path of the proxy URL. This only needs to be changed if the apps proxy URL is overwritten in the Shopify store.

        :return: The payment_proxy_path of this ShopifyIntegration.
        :rtype: str
        """
        return self._payment_proxy_path

    @payment_proxy_path.setter
    def payment_proxy_path(self, payment_proxy_path):
        """Sets the payment_proxy_path of this ShopifyIntegration.

            Define the path of the proxy URL. This only needs to be changed if the apps proxy URL is overwritten in the Shopify store.

        :param payment_proxy_path: The payment_proxy_path of this ShopifyIntegration.
        :type: str
        """

        self._payment_proxy_path = payment_proxy_path
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this ShopifyIntegration.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this ShopifyIntegration.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this ShopifyIntegration.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this ShopifyIntegration.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def replace_payment_method_image(self):
        """Gets the replace_payment_method_image of this ShopifyIntegration.

            

        :return: The replace_payment_method_image of this ShopifyIntegration.
        :rtype: bool
        """
        return self._replace_payment_method_image

    @replace_payment_method_image.setter
    def replace_payment_method_image(self, replace_payment_method_image):
        """Sets the replace_payment_method_image of this ShopifyIntegration.

            

        :param replace_payment_method_image: The replace_payment_method_image of this ShopifyIntegration.
        :type: bool
        """

        self._replace_payment_method_image = replace_payment_method_image
    
    @property
    def shop_name(self):
        """Gets the shop_name of this ShopifyIntegration.

            The store address is used to link a specific Shopify shop to this integration. This is the name used in the Shopifys admin URL: [storeAddress].myshopify.com

        :return: The shop_name of this ShopifyIntegration.
        :rtype: str
        """
        return self._shop_name

    @shop_name.setter
    def shop_name(self, shop_name):
        """Sets the shop_name of this ShopifyIntegration.

            The store address is used to link a specific Shopify shop to this integration. This is the name used in the Shopifys admin URL: [storeAddress].myshopify.com

        :param shop_name: The shop_name of this ShopifyIntegration.
        :type: str
        """
        if shop_name is not None and len(shop_name) > 100:
            raise ValueError("Invalid value for `shop_name`, length must be less than or equal to `100`")

        self._shop_name = shop_name
    
    @property
    def show_payment_information(self):
        """Gets the show_payment_information of this ShopifyIntegration.

            

        :return: The show_payment_information of this ShopifyIntegration.
        :rtype: bool
        """
        return self._show_payment_information

    @show_payment_information.setter
    def show_payment_information(self, show_payment_information):
        """Sets the show_payment_information of this ShopifyIntegration.

            

        :param show_payment_information: The show_payment_information of this ShopifyIntegration.
        :type: bool
        """

        self._show_payment_information = show_payment_information
    
    @property
    def show_subscription_information(self):
        """Gets the show_subscription_information of this ShopifyIntegration.

            

        :return: The show_subscription_information of this ShopifyIntegration.
        :rtype: bool
        """
        return self._show_subscription_information

    @show_subscription_information.setter
    def show_subscription_information(self, show_subscription_information):
        """Sets the show_subscription_information of this ShopifyIntegration.

            

        :param show_subscription_information: The show_subscription_information of this ShopifyIntegration.
        :type: bool
        """

        self._show_subscription_information = show_subscription_information
    
    @property
    def space_id(self):
        """Gets the space_id of this ShopifyIntegration.

            

        :return: The space_id of this ShopifyIntegration.
        :rtype: int
        """
        return self._space_id

    @space_id.setter
    def space_id(self, space_id):
        """Sets the space_id of this ShopifyIntegration.

            

        :param space_id: The space_id of this ShopifyIntegration.
        :type: int
        """

        self._space_id = space_id
    
    @property
    def space_view_id(self):
        """Gets the space_view_id of this ShopifyIntegration.

            

        :return: The space_view_id of this ShopifyIntegration.
        :rtype: int
        """
        return self._space_view_id

    @space_view_id.setter
    def space_view_id(self, space_view_id):
        """Sets the space_view_id of this ShopifyIntegration.

            

        :param space_view_id: The space_view_id of this ShopifyIntegration.
        :type: int
        """

        self._space_view_id = space_view_id
    
    @property
    def state(self):
        """Gets the state of this ShopifyIntegration.

            The object's current state.

        :return: The state of this ShopifyIntegration.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ShopifyIntegration.

            The object's current state.

        :param state: The state of this ShopifyIntegration.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def subscription_app_version(self):
        """Gets the subscription_app_version of this ShopifyIntegration.

            

        :return: The subscription_app_version of this ShopifyIntegration.
        :rtype: ShopifyIntegrationSubscriptionAppVersion
        """
        return self._subscription_app_version

    @subscription_app_version.setter
    def subscription_app_version(self, subscription_app_version):
        """Sets the subscription_app_version of this ShopifyIntegration.

            

        :param subscription_app_version: The subscription_app_version of this ShopifyIntegration.
        :type: ShopifyIntegrationSubscriptionAppVersion
        """

        self._subscription_app_version = subscription_app_version
    
    @property
    def subscription_installed(self):
        """Gets the subscription_installed of this ShopifyIntegration.

            

        :return: The subscription_installed of this ShopifyIntegration.
        :rtype: bool
        """
        return self._subscription_installed

    @subscription_installed.setter
    def subscription_installed(self, subscription_installed):
        """Sets the subscription_installed of this ShopifyIntegration.

            

        :param subscription_installed: The subscription_installed of this ShopifyIntegration.
        :type: bool
        """

        self._subscription_installed = subscription_installed
    
    @property
    def subscription_proxy_path(self):
        """Gets the subscription_proxy_path of this ShopifyIntegration.

            Define the path of the proxy URL. This only needs to be changed if the apps proxy URL is overwritten in the Shopify store.

        :return: The subscription_proxy_path of this ShopifyIntegration.
        :rtype: str
        """
        return self._subscription_proxy_path

    @subscription_proxy_path.setter
    def subscription_proxy_path(self, subscription_proxy_path):
        """Sets the subscription_proxy_path of this ShopifyIntegration.

            Define the path of the proxy URL. This only needs to be changed if the apps proxy URL is overwritten in the Shopify store.

        :param subscription_proxy_path: The subscription_proxy_path of this ShopifyIntegration.
        :type: str
        """

        self._subscription_proxy_path = subscription_proxy_path
    
    @property
    def version(self):
        """Gets the version of this ShopifyIntegration.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this ShopifyIntegration.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ShopifyIntegration.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this ShopifyIntegration.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ShopifyIntegration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ShopifyIntegration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from __future__ import absolute_import

from .abstract_account_update import AbstractAccountUpdate
from .abstract_application_user_update import AbstractApplicationUserUpdate
from .abstract_customer_active import AbstractCustomerActive
from .abstract_customer_address_active import AbstractCustomerAddressActive
from .abstract_customer_comment_active import AbstractCustomerCommentActive
from .abstract_debt_collection_case_update import AbstractDebtCollectionCaseUpdate
from .abstract_human_user_update import AbstractHumanUserUpdate
from .abstract_payment_link_update import AbstractPaymentLinkUpdate
from .abstract_refund_comment_active import AbstractRefundCommentActive
from .abstract_shopify_subscription_product_update import AbstractShopifySubscriptionProductUpdate
from .abstract_space_update import AbstractSpaceUpdate
from .abstract_subscriber_update import AbstractSubscriberUpdate
from .abstract_subscription_affiliate_update import AbstractSubscriptionAffiliateUpdate
from .abstract_subscription_metric_update import AbstractSubscriptionMetricUpdate
from .abstract_subscription_product_active import AbstractSubscriptionProductActive
from .abstract_token_update import AbstractTokenUpdate
from .abstract_transaction_comment_active import AbstractTransactionCommentActive
from .abstract_transaction_invoice_comment_active import AbstractTransactionInvoiceCommentActive
from .abstract_transaction_pending import AbstractTransactionPending
from .abstract_webhook_listener_update import AbstractWebhookListenerUpdate
from .abstract_webhook_url_update import AbstractWebhookUrlUpdate
from .account import Account
from .account_state import AccountState
from .account_type import AccountType
from .address import Address
from .address_create import AddressCreate
from .analytics_query import AnalyticsQuery
from .analytics_query_execution import AnalyticsQueryExecution
from .analytics_query_execution_state import AnalyticsQueryExecutionState
from .analytics_query_result_batch import AnalyticsQueryResultBatch
from .analytics_schema_column import AnalyticsSchemaColumn
from .analytics_schema_table import AnalyticsSchemaTable
from .authenticated_card_data_create import AuthenticatedCardDataCreate
from .bank_account import BankAccount
from .bank_account_environment import BankAccountEnvironment
from .bank_account_state import BankAccountState
from .bank_account_type import BankAccountType
from .bank_transaction import BankTransaction
from .bank_transaction_flow_direction import BankTransactionFlowDirection
from .bank_transaction_source import BankTransactionSource
from .bank_transaction_state import BankTransactionState
from .bank_transaction_type import BankTransactionType
from .card_authentication_response import CardAuthenticationResponse
from .card_authentication_version import CardAuthenticationVersion
from .card_cryptogram import CardCryptogram
from .card_cryptogram_create import CardCryptogramCreate
from .card_cryptogram_type import CardCryptogramType
from .cardholder_authentication import CardholderAuthentication
from .cardholder_authentication_create import CardholderAuthenticationCreate
from .charge_attempt_environment import ChargeAttemptEnvironment
from .charge_attempt_state import ChargeAttemptState
from .charge_flow import ChargeFlow
from .charge_flow_level_configuration import ChargeFlowLevelConfiguration
from .charge_flow_level_configuration_type import ChargeFlowLevelConfigurationType
from .charge_flow_level_state import ChargeFlowLevelState
from .charge_state import ChargeState
from .charge_type import ChargeType
from .client_error import ClientError
from .client_error_type import ClientErrorType
from .completion_line_item import CompletionLineItem
from .completion_line_item_create import CompletionLineItemCreate
from .condition import Condition
from .condition_type import ConditionType
from .connector_invocation_stage import ConnectorInvocationStage
from .creation_entity_state import CreationEntityState
from .criteria_operator import CriteriaOperator
from .currency_bank_account import CurrencyBankAccount
from .customer import Customer
from .customer_address import CustomerAddress
from .customer_address_type import CustomerAddressType
from .customer_comment import CustomerComment
from .customer_postal_address import CustomerPostalAddress
from .customer_postal_address_create import CustomerPostalAddressCreate
from .customers_presence import CustomersPresence
from .data_collection_type import DataCollectionType
from .debt_collection_case import DebtCollectionCase
from .debt_collection_case_document import DebtCollectionCaseDocument
from .debt_collection_case_source import DebtCollectionCaseSource
from .debt_collection_case_state import DebtCollectionCaseState
from .debt_collection_environment import DebtCollectionEnvironment
from .debt_collection_receipt import DebtCollectionReceipt
from .debt_collection_receipt_source import DebtCollectionReceiptSource
from .debt_collector import DebtCollector
from .debt_collector_condition import DebtCollectorCondition
from .debt_collector_condition_type import DebtCollectorConditionType
from .debt_collector_configuration import DebtCollectorConfiguration
from .delivery_indication_decision_reason import DeliveryIndicationDecisionReason
from .delivery_indication_state import DeliveryIndicationState
from .document_template import DocumentTemplate
from .document_template_type import DocumentTemplateType
from .document_template_type_group import DocumentTemplateTypeGroup
from .entity_export_request import EntityExportRequest
from .entity_query import EntityQuery
from .entity_query_filter import EntityQueryFilter
from .entity_query_filter_type import EntityQueryFilterType
from .entity_query_order_by import EntityQueryOrderBy
from .entity_query_order_by_type import EntityQueryOrderByType
from .environment import Environment
from .external_transfer_bank_transaction import ExternalTransferBankTransaction
from .failure_category import FailureCategory
from .failure_reason import FailureReason
from .feature import Feature
from .feature_category import FeatureCategory
from .gender import Gender
from .human_user import HumanUser
from .installment_calculated_plan import InstallmentCalculatedPlan
from .installment_calculated_slice import InstallmentCalculatedSlice
from .installment_payment import InstallmentPayment
from .installment_payment_slice_state import InstallmentPaymentSliceState
from .installment_payment_state import InstallmentPaymentState
from .installment_plan_configuration import InstallmentPlanConfiguration
from .installment_plan_slice_configuration import InstallmentPlanSliceConfiguration
from .internal_transfer_bank_transaction import InternalTransferBankTransaction
from .invoice_reconciliation_record_invoice_link import InvoiceReconciliationRecordInvoiceLink
from .invoice_reconciliation_record_rejection_status import InvoiceReconciliationRecordRejectionStatus
from .invoice_reconciliation_record_state import InvoiceReconciliationRecordState
from .invoice_reconciliation_record_type import InvoiceReconciliationRecordType
from .invoice_reimbursement import InvoiceReimbursement
from .invoice_reimbursement_state import InvoiceReimbursementState
from .label import Label
from .label_descriptor import LabelDescriptor
from .label_descriptor_category import LabelDescriptorCategory
from .label_descriptor_group import LabelDescriptorGroup
from .label_descriptor_type import LabelDescriptorType
from .legal_organization_form import LegalOrganizationForm
from .line_item import LineItem
from .line_item_attribute import LineItemAttribute
from .line_item_attribute_create import LineItemAttributeCreate
from .line_item_create import LineItemCreate
from .line_item_reduction import LineItemReduction
from .line_item_reduction_create import LineItemReductionCreate
from .line_item_type import LineItemType
from .localized_string import LocalizedString
from .manual_task import ManualTask
from .manual_task_action import ManualTaskAction
from .manual_task_action_style import ManualTaskActionStyle
from .manual_task_state import ManualTaskState
from .manual_task_type import ManualTaskType
from .metric_usage import MetricUsage
from .one_click_payment_mode import OneClickPaymentMode
from .payment_adjustment import PaymentAdjustment
from .payment_adjustment_type import PaymentAdjustmentType
from .payment_app_charge_attempt_target_state import PaymentAppChargeAttemptTargetState
from .payment_app_charge_attempt_update_request import PaymentAppChargeAttemptUpdateRequest
from .payment_app_completion_configuration import PaymentAppCompletionConfiguration
from .payment_app_completion_configuration_create import PaymentAppCompletionConfigurationCreate
from .payment_app_completion_target_state import PaymentAppCompletionTargetState
from .payment_app_completion_update_request import PaymentAppCompletionUpdateRequest
from .payment_app_connector import PaymentAppConnector
from .payment_app_connector_creation_request import PaymentAppConnectorCreationRequest
from .payment_app_connector_state import PaymentAppConnectorState
from .payment_app_processor import PaymentAppProcessor
from .payment_app_processor_creation_request import PaymentAppProcessorCreationRequest
from .payment_app_processor_state import PaymentAppProcessorState
from .payment_app_refund_configuration import PaymentAppRefundConfiguration
from .payment_app_refund_configuration_create import PaymentAppRefundConfigurationCreate
from .payment_app_refund_target_state import PaymentAppRefundTargetState
from .payment_app_refund_update_request import PaymentAppRefundUpdateRequest
from .payment_app_void_target_state import PaymentAppVoidTargetState
from .payment_app_void_update_request import PaymentAppVoidUpdateRequest
from .payment_connector import PaymentConnector
from .payment_connector_configuration import PaymentConnectorConfiguration
from .payment_connector_feature import PaymentConnectorFeature
from .payment_contract import PaymentContract
from .payment_contract_state import PaymentContractState
from .payment_contract_type import PaymentContractType
from .payment_information_hash import PaymentInformationHash
from .payment_information_hash_type import PaymentInformationHashType
from .payment_initiation_advice_file import PaymentInitiationAdviceFile
from .payment_initiation_advice_file_state import PaymentInitiationAdviceFileState
from .payment_link import PaymentLink
from .payment_link_address_handling_mode import PaymentLinkAddressHandlingMode
from .payment_link_protection_mode import PaymentLinkProtectionMode
from .payment_link_update import PaymentLinkUpdate
from .payment_method import PaymentMethod
from .payment_method_brand import PaymentMethodBrand
from .payment_method_configuration import PaymentMethodConfiguration
from .payment_primary_risk_taker import PaymentPrimaryRiskTaker
from .payment_processor import PaymentProcessor
from .payment_processor_configuration import PaymentProcessorConfiguration
from .payment_terminal import PaymentTerminal
from .payment_terminal_address import PaymentTerminalAddress
from .payment_terminal_configuration import PaymentTerminalConfiguration
from .payment_terminal_configuration_state import PaymentTerminalConfigurationState
from .payment_terminal_configuration_version import PaymentTerminalConfigurationVersion
from .payment_terminal_configuration_version_state import PaymentTerminalConfigurationVersionState
from .payment_terminal_dcc_transaction_sum import PaymentTerminalDccTransactionSum
from .payment_terminal_location import PaymentTerminalLocation
from .payment_terminal_location_state import PaymentTerminalLocationState
from .payment_terminal_location_version import PaymentTerminalLocationVersion
from .payment_terminal_location_version_state import PaymentTerminalLocationVersionState
from .payment_terminal_receipt_type import PaymentTerminalReceiptType
from .payment_terminal_state import PaymentTerminalState
from .payment_terminal_transaction_sum import PaymentTerminalTransactionSum
from .payment_terminal_transaction_summary import PaymentTerminalTransactionSummary
from .payment_terminal_transaction_summary_fetch_request import PaymentTerminalTransactionSummaryFetchRequest
from .payment_terminal_type import PaymentTerminalType
from .permission import Permission
from .persistable_currency_amount import PersistableCurrencyAmount
from .persistable_currency_amount_update import PersistableCurrencyAmountUpdate
from .product_fee_type import ProductFeeType
from .product_metered_fee import ProductMeteredFee
from .product_metered_fee_update import ProductMeteredFeeUpdate
from .product_metered_tier_fee import ProductMeteredTierFee
from .product_metered_tier_fee_update import ProductMeteredTierFeeUpdate
from .product_metered_tier_pricing import ProductMeteredTierPricing
from .product_period_fee import ProductPeriodFee
from .product_period_fee_update import ProductPeriodFeeUpdate
from .product_setup_fee import ProductSetupFee
from .product_setup_fee_update import ProductSetupFeeUpdate
from .recurring_indicator import RecurringIndicator
from .refund import Refund
from .refund_comment import RefundComment
from .refund_create import RefundCreate
from .refund_state import RefundState
from .refund_type import RefundType
from .rendered_document import RenderedDocument
from .rendered_terminal_receipt import RenderedTerminalReceipt
from .rendered_terminal_transaction_summary import RenderedTerminalTransactionSummary
from .resource_path import ResourcePath
from .resource_state import ResourceState
from .rest_address_format import RestAddressFormat
from .rest_address_format_field import RestAddressFormatField
from .rest_country import RestCountry
from .rest_country_state import RestCountryState
from .rest_currency import RestCurrency
from .rest_language import RestLanguage
from .role import Role
from .role_state import RoleState
from .sales_channel import SalesChannel
from .scope import Scope
from .server_error import ServerError
from .shopify_additional_line_item_data import ShopifyAdditionalLineItemData
from .shopify_integration import ShopifyIntegration
from .shopify_integration_payment_app_version import ShopifyIntegrationPaymentAppVersion
from .shopify_integration_subscription_app_version import ShopifyIntegrationSubscriptionAppVersion
from .shopify_recurring_order_state import ShopifyRecurringOrderState
from .shopify_recurring_order_update_request import ShopifyRecurringOrderUpdateRequest
from .shopify_subscriber import ShopifySubscriber
from .shopify_subscriber_active import ShopifySubscriberActive
from .shopify_subscriber_creation import ShopifySubscriberCreation
from .shopify_subscriber_state import ShopifySubscriberState
from .shopify_subscription import ShopifySubscription
from .shopify_subscription_address_create import ShopifySubscriptionAddressCreate
from .shopify_subscription_billing_interval_unit import ShopifySubscriptionBillingIntervalUnit
from .shopify_subscription_creation_request import ShopifySubscriptionCreationRequest
from .shopify_subscription_model_billing_configuration import ShopifySubscriptionModelBillingConfiguration
from .shopify_subscription_model_item import ShopifySubscriptionModelItem
from .shopify_subscription_model_tax_line import ShopifySubscriptionModelTaxLine
from .shopify_subscription_product import ShopifySubscriptionProduct
from .shopify_subscription_product_pricing_option import ShopifySubscriptionProductPricingOption
from .shopify_subscription_product_state import ShopifySubscriptionProductState
from .shopify_subscription_state import ShopifySubscriptionState
from .shopify_subscription_suspension import ShopifySubscriptionSuspension
from .shopify_subscription_suspension_create import ShopifySubscriptionSuspensionCreate
from .shopify_subscription_suspension_initiator import ShopifySubscriptionSuspensionInitiator
from .shopify_subscription_suspension_state import ShopifySubscriptionSuspensionState
from .shopify_subscription_suspension_type import ShopifySubscriptionSuspensionType
from .shopify_subscription_update_addresses_request import ShopifySubscriptionUpdateAddressesRequest
from .shopify_subscription_update_request import ShopifySubscriptionUpdateRequest
from .shopify_subscription_version import ShopifySubscriptionVersion
from .shopify_subscription_version_item import ShopifySubscriptionVersionItem
from .shopify_subscription_version_item_price_strategy import ShopifySubscriptionVersionItemPriceStrategy
from .shopify_subscription_version_state import ShopifySubscriptionVersionState
from .shopify_subscription_weekday import ShopifySubscriptionWeekday
from .shopify_tax_line import ShopifyTaxLine
from .shopify_transaction_state import ShopifyTransactionState
from .space import Space
from .space_address import SpaceAddress
from .space_address_create import SpaceAddressCreate
from .space_reference import SpaceReference
from .space_reference_state import SpaceReferenceState
from .space_view import SpaceView
from .static_value import StaticValue
from .subscriber import Subscriber
from .subscriber_update import SubscriberUpdate
from .subscription import Subscription
from .subscription_affiliate import SubscriptionAffiliate
from .subscription_affiliate_update import SubscriptionAffiliateUpdate
from .subscription_change_request import SubscriptionChangeRequest
from .subscription_charge import SubscriptionCharge
from .subscription_charge_create import SubscriptionChargeCreate
from .subscription_charge_processing_type import SubscriptionChargeProcessingType
from .subscription_charge_state import SubscriptionChargeState
from .subscription_charge_type import SubscriptionChargeType
from .subscription_component_configuration import SubscriptionComponentConfiguration
from .subscription_component_reference_configuration import SubscriptionComponentReferenceConfiguration
from .subscription_create_request import SubscriptionCreateRequest
from .subscription_ledger_entry import SubscriptionLedgerEntry
from .subscription_ledger_entry_create import SubscriptionLedgerEntryCreate
from .subscription_ledger_entry_state import SubscriptionLedgerEntryState
from .subscription_metric import SubscriptionMetric
from .subscription_metric_type import SubscriptionMetricType
from .subscription_metric_update import SubscriptionMetricUpdate
from .subscription_metric_usage_report import SubscriptionMetricUsageReport
from .subscription_metric_usage_report_create import SubscriptionMetricUsageReportCreate
from .subscription_period_bill import SubscriptionPeriodBill
from .subscription_period_bill_state import SubscriptionPeriodBillState
from .subscription_product import SubscriptionProduct
from .subscription_product_component import SubscriptionProductComponent
from .subscription_product_component_group import SubscriptionProductComponentGroup
from .subscription_product_component_group_update import SubscriptionProductComponentGroupUpdate
from .subscription_product_component_reference import SubscriptionProductComponentReference
from .subscription_product_component_reference_state import SubscriptionProductComponentReferenceState
from .subscription_product_component_update import SubscriptionProductComponentUpdate
from .subscription_product_retirement import SubscriptionProductRetirement
from .subscription_product_retirement_create import SubscriptionProductRetirementCreate
from .subscription_product_state import SubscriptionProductState
from .subscription_product_version import SubscriptionProductVersion
from .subscription_product_version_pending import SubscriptionProductVersionPending
from .subscription_product_version_retirement import SubscriptionProductVersionRetirement
from .subscription_product_version_retirement_create import SubscriptionProductVersionRetirementCreate
from .subscription_product_version_state import SubscriptionProductVersionState
from .subscription_state import SubscriptionState
from .subscription_suspension import SubscriptionSuspension
from .subscription_suspension_action import SubscriptionSuspensionAction
from .subscription_suspension_create import SubscriptionSuspensionCreate
from .subscription_suspension_reason import SubscriptionSuspensionReason
from .subscription_suspension_state import SubscriptionSuspensionState
from .subscription_update import SubscriptionUpdate
from .subscription_update_request import SubscriptionUpdateRequest
from .subscription_version import SubscriptionVersion
from .subscription_version_state import SubscriptionVersionState
from .tax import Tax
from .tax_calculation import TaxCalculation
from .tax_class import TaxClass
from .tax_create import TaxCreate
from .tenant_database import TenantDatabase
from .terminal_receipt_fetch_request import TerminalReceiptFetchRequest
from .terminal_receipt_format import TerminalReceiptFormat
from .token import Token
from .token_version import TokenVersion
from .token_version_state import TokenVersionState
from .token_version_type import TokenVersionType
from .tokenization_mode import TokenizationMode
from .tokenized_card_data import TokenizedCardData
from .tokenized_card_data_create import TokenizedCardDataCreate
from .transaction import Transaction
from .transaction_aware_entity import TransactionAwareEntity
from .transaction_comment import TransactionComment
from .transaction_completion_behavior import TransactionCompletionBehavior
from .transaction_completion_mode import TransactionCompletionMode
from .transaction_completion_request import TransactionCompletionRequest
from .transaction_completion_state import TransactionCompletionState
from .transaction_environment_selection_strategy import TransactionEnvironmentSelectionStrategy
from .transaction_group import TransactionGroup
from .transaction_group_state import TransactionGroupState
from .transaction_invoice_comment import TransactionInvoiceComment
from .transaction_invoice_replacement import TransactionInvoiceReplacement
from .transaction_invoice_state import TransactionInvoiceState
from .transaction_line_item_version_create import TransactionLineItemVersionCreate
from .transaction_line_item_version_state import TransactionLineItemVersionState
from .transaction_state import TransactionState
from .transaction_user_interface_type import TransactionUserInterfaceType
from .transaction_void_mode import TransactionVoidMode
from .transaction_void_state import TransactionVoidState
from .two_factor_authentication_type import TwoFactorAuthenticationType
from .user import User
from .user_account_role import UserAccountRole
from .user_space_role import UserSpaceRole
from .user_type import UserType
from .wallet_type import WalletType
from .web_app_confirmation_request import WebAppConfirmationRequest
from .web_app_confirmation_response import WebAppConfirmationResponse
from .webhook_encryption_public_key import WebhookEncryptionPublicKey
from .webhook_identity import WebhookIdentity
from .webhook_listener import WebhookListener
from .webhook_listener_entity import WebhookListenerEntity
from .webhook_url import WebhookUrl
from .account_create import AccountCreate
from .account_update import AccountUpdate
from .application_user import ApplicationUser
from .application_user_create import ApplicationUserCreate
from .application_user_update import ApplicationUserUpdate
from .authenticated_card_data import AuthenticatedCardData
from .charge import Charge
from .charge_attempt import ChargeAttempt
from .charge_bank_transaction import ChargeBankTransaction
from .charge_flow_level import ChargeFlowLevel
from .charge_flow_level_payment_link import ChargeFlowLevelPaymentLink
from .connector_invocation import ConnectorInvocation
from .customer_active import CustomerActive
from .customer_address_active import CustomerAddressActive
from .customer_address_create import CustomerAddressCreate
from .customer_comment_active import CustomerCommentActive
from .customer_comment_create import CustomerCommentCreate
from .customer_create import CustomerCreate
from .debt_collection_case_create import DebtCollectionCaseCreate
from .debt_collection_case_update import DebtCollectionCaseUpdate
from .delivery_indication import DeliveryIndication
from .human_user_create import HumanUserCreate
from .human_user_update import HumanUserUpdate
from .installment_payment_slice import InstallmentPaymentSlice
from .invoice_reconciliation_record import InvoiceReconciliationRecord
from .invoice_reimbursement_with_refund_reference import InvoiceReimbursementWithRefundReference
from .payment_link_active import PaymentLinkActive
from .payment_link_create import PaymentLinkCreate
from .refund_bank_transaction import RefundBankTransaction
from .refund_comment_active import RefundCommentActive
from .refund_comment_create import RefundCommentCreate
from .refund_recovery_bank_transaction import RefundRecoveryBankTransaction
from .shopify_recurring_order import ShopifyRecurringOrder
from .shopify_subscription_address import ShopifySubscriptionAddress
from .shopify_subscription_product_create import ShopifySubscriptionProductCreate
from .shopify_subscription_product_update import ShopifySubscriptionProductUpdate
from .shopify_transaction import ShopifyTransaction
from .space_create import SpaceCreate
from .space_update import SpaceUpdate
from .subscriber_active import SubscriberActive
from .subscriber_create import SubscriberCreate
from .subscription_affiliate_create import SubscriptionAffiliateCreate
from .subscription_affiliate_deleted import SubscriptionAffiliateDeleted
from .subscription_affiliate_inactive import SubscriptionAffiliateInactive
from .subscription_metric_active import SubscriptionMetricActive
from .subscription_metric_create import SubscriptionMetricCreate
from .subscription_pending import SubscriptionPending
from .subscription_product_active import SubscriptionProductActive
from .subscription_product_create import SubscriptionProductCreate
from .subscription_suspension_running import SubscriptionSuspensionRunning
from .token_create import TokenCreate
from .token_update import TokenUpdate
from .transaction_comment_active import TransactionCommentActive
from .transaction_comment_create import TransactionCommentCreate
from .transaction_completion import TransactionCompletion
from .transaction_create import TransactionCreate
from .transaction_invoice import TransactionInvoice
from .transaction_invoice_comment_active import TransactionInvoiceCommentActive
from .transaction_invoice_comment_create import TransactionInvoiceCommentCreate
from .transaction_line_item_version import TransactionLineItemVersion
from .transaction_pending import TransactionPending
from .transaction_void import TransactionVoid
from .webhook_listener_create import WebhookListenerCreate
from .webhook_listener_update import WebhookListenerUpdate
from .webhook_url_create import WebhookUrlCreate
from .webhook_url_update import WebhookUrlUpdate
from .application_user_create_with_mac_key import ApplicationUserCreateWithMacKey
from .subscription_affiliate_deleting import SubscriptionAffiliateDeleting



# coding: utf-8
import pprint
import six
from enum import Enum
from . import SubscriptionUpdate


class SubscriptionPending(SubscriptionUpdate):

    swagger_types = {
    
        'reference': 'str',
        'subscriber': 'int',
        'token': 'int',
    }

    attribute_map = {
        'reference': 'reference','subscriber': 'subscriber','token': 'token',
    }

    
    _reference = None
    _subscriber = None
    _token = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.reference = kwargs.get('reference', None)
        self.subscriber = kwargs.get('subscriber', None)
        self.token = kwargs.get('token', None)
        super().__init__(**kwargs)
        self.swagger_types.update(super().swagger_types)
        self.attribute_map.update(super().attribute_map)

    
    @property
    def reference(self):
        """Gets the reference of this SubscriptionPending.

            

        :return: The reference of this SubscriptionPending.
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this SubscriptionPending.

            

        :param reference: The reference of this SubscriptionPending.
        :type: str
        """
        if reference is not None and len(reference) > 100:
            raise ValueError("Invalid value for `reference`, length must be less than or equal to `100`")

        self._reference = reference
    
    @property
    def subscriber(self):
        """Gets the subscriber of this SubscriptionPending.

            

        :return: The subscriber of this SubscriptionPending.
        :rtype: int
        """
        return self._subscriber

    @subscriber.setter
    def subscriber(self, subscriber):
        """Sets the subscriber of this SubscriptionPending.

            

        :param subscriber: The subscriber of this SubscriptionPending.
        :type: int
        """

        self._subscriber = subscriber
    
    @property
    def token(self):
        """Gets the token of this SubscriptionPending.

            

        :return: The token of this SubscriptionPending.
        :rtype: int
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this SubscriptionPending.

            

        :param token: The token of this SubscriptionPending.
        :type: int
        """

        self._token = token
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionPending, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionPending):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class ShopifySubscriptionSuspension:

    swagger_types = {
    
        'created_by': 'int',
        'created_on': 'datetime',
        'ended_by': 'int',
        'ended_on': 'datetime',
        'id': 'int',
        'initiator': 'ShopifySubscriptionSuspensionInitiator',
        'linked_space_id': 'int',
        'planned_end_date': 'datetime',
        'shop': 'int',
        'state': 'ShopifySubscriptionSuspensionState',
        'subscription': 'ShopifySubscription',
        'type': 'ShopifySubscriptionSuspensionType',
        'version': 'int',
    }

    attribute_map = {
        'created_by': 'createdBy','created_on': 'createdOn','ended_by': 'endedBy','ended_on': 'endedOn','id': 'id','initiator': 'initiator','linked_space_id': 'linkedSpaceId','planned_end_date': 'plannedEndDate','shop': 'shop','state': 'state','subscription': 'subscription','type': 'type','version': 'version',
    }

    
    _created_by = None
    _created_on = None
    _ended_by = None
    _ended_on = None
    _id = None
    _initiator = None
    _linked_space_id = None
    _planned_end_date = None
    _shop = None
    _state = None
    _subscription = None
    _type = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.created_by = kwargs.get('created_by', None)
        self.created_on = kwargs.get('created_on', None)
        self.ended_by = kwargs.get('ended_by', None)
        self.ended_on = kwargs.get('ended_on', None)
        self.id = kwargs.get('id', None)
        self.initiator = kwargs.get('initiator', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.planned_end_date = kwargs.get('planned_end_date', None)
        self.shop = kwargs.get('shop', None)
        self.state = kwargs.get('state', None)
        self.subscription = kwargs.get('subscription', None)
        self.type = kwargs.get('type', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def created_by(self):
        """Gets the created_by of this ShopifySubscriptionSuspension.

            

        :return: The created_by of this ShopifySubscriptionSuspension.
        :rtype: int
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this ShopifySubscriptionSuspension.

            

        :param created_by: The created_by of this ShopifySubscriptionSuspension.
        :type: int
        """

        self._created_by = created_by
    
    @property
    def created_on(self):
        """Gets the created_on of this ShopifySubscriptionSuspension.

            

        :return: The created_on of this ShopifySubscriptionSuspension.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this ShopifySubscriptionSuspension.

            

        :param created_on: The created_on of this ShopifySubscriptionSuspension.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def ended_by(self):
        """Gets the ended_by of this ShopifySubscriptionSuspension.

            

        :return: The ended_by of this ShopifySubscriptionSuspension.
        :rtype: int
        """
        return self._ended_by

    @ended_by.setter
    def ended_by(self, ended_by):
        """Sets the ended_by of this ShopifySubscriptionSuspension.

            

        :param ended_by: The ended_by of this ShopifySubscriptionSuspension.
        :type: int
        """

        self._ended_by = ended_by
    
    @property
    def ended_on(self):
        """Gets the ended_on of this ShopifySubscriptionSuspension.

            

        :return: The ended_on of this ShopifySubscriptionSuspension.
        :rtype: datetime
        """
        return self._ended_on

    @ended_on.setter
    def ended_on(self, ended_on):
        """Sets the ended_on of this ShopifySubscriptionSuspension.

            

        :param ended_on: The ended_on of this ShopifySubscriptionSuspension.
        :type: datetime
        """

        self._ended_on = ended_on
    
    @property
    def id(self):
        """Gets the id of this ShopifySubscriptionSuspension.

            A unique identifier for the object.

        :return: The id of this ShopifySubscriptionSuspension.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ShopifySubscriptionSuspension.

            A unique identifier for the object.

        :param id: The id of this ShopifySubscriptionSuspension.
        :type: int
        """

        self._id = id
    
    @property
    def initiator(self):
        """Gets the initiator of this ShopifySubscriptionSuspension.

            

        :return: The initiator of this ShopifySubscriptionSuspension.
        :rtype: ShopifySubscriptionSuspensionInitiator
        """
        return self._initiator

    @initiator.setter
    def initiator(self, initiator):
        """Sets the initiator of this ShopifySubscriptionSuspension.

            

        :param initiator: The initiator of this ShopifySubscriptionSuspension.
        :type: ShopifySubscriptionSuspensionInitiator
        """

        self._initiator = initiator
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this ShopifySubscriptionSuspension.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this ShopifySubscriptionSuspension.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this ShopifySubscriptionSuspension.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this ShopifySubscriptionSuspension.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def planned_end_date(self):
        """Gets the planned_end_date of this ShopifySubscriptionSuspension.

            

        :return: The planned_end_date of this ShopifySubscriptionSuspension.
        :rtype: datetime
        """
        return self._planned_end_date

    @planned_end_date.setter
    def planned_end_date(self, planned_end_date):
        """Sets the planned_end_date of this ShopifySubscriptionSuspension.

            

        :param planned_end_date: The planned_end_date of this ShopifySubscriptionSuspension.
        :type: datetime
        """

        self._planned_end_date = planned_end_date
    
    @property
    def shop(self):
        """Gets the shop of this ShopifySubscriptionSuspension.

            

        :return: The shop of this ShopifySubscriptionSuspension.
        :rtype: int
        """
        return self._shop

    @shop.setter
    def shop(self, shop):
        """Sets the shop of this ShopifySubscriptionSuspension.

            

        :param shop: The shop of this ShopifySubscriptionSuspension.
        :type: int
        """

        self._shop = shop
    
    @property
    def state(self):
        """Gets the state of this ShopifySubscriptionSuspension.

            The object's current state.

        :return: The state of this ShopifySubscriptionSuspension.
        :rtype: ShopifySubscriptionSuspensionState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ShopifySubscriptionSuspension.

            The object's current state.

        :param state: The state of this ShopifySubscriptionSuspension.
        :type: ShopifySubscriptionSuspensionState
        """

        self._state = state
    
    @property
    def subscription(self):
        """Gets the subscription of this ShopifySubscriptionSuspension.

            

        :return: The subscription of this ShopifySubscriptionSuspension.
        :rtype: ShopifySubscription
        """
        return self._subscription

    @subscription.setter
    def subscription(self, subscription):
        """Sets the subscription of this ShopifySubscriptionSuspension.

            

        :param subscription: The subscription of this ShopifySubscriptionSuspension.
        :type: ShopifySubscription
        """

        self._subscription = subscription
    
    @property
    def type(self):
        """Gets the type of this ShopifySubscriptionSuspension.

            

        :return: The type of this ShopifySubscriptionSuspension.
        :rtype: ShopifySubscriptionSuspensionType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ShopifySubscriptionSuspension.

            

        :param type: The type of this ShopifySubscriptionSuspension.
        :type: ShopifySubscriptionSuspensionType
        """

        self._type = type
    
    @property
    def version(self):
        """Gets the version of this ShopifySubscriptionSuspension.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this ShopifySubscriptionSuspension.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ShopifySubscriptionSuspension.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this ShopifySubscriptionSuspension.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ShopifySubscriptionSuspension, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ShopifySubscriptionSuspension):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class ProductMeteredFeeUpdate:

    swagger_types = {
    
        'id': 'int',
        'version': 'int',
        'component': 'int',
        'description': 'dict(str, str)',
        'metric': 'int',
        'name': 'dict(str, str)',
        'tier_pricing': 'ProductMeteredTierPricing',
    }

    attribute_map = {
        'id': 'id','version': 'version','component': 'component','description': 'description','metric': 'metric','name': 'name','tier_pricing': 'tierPricing',
    }

    
    _id = None
    _version = None
    _component = None
    _description = None
    _metric = None
    _name = None
    _tier_pricing = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.id = kwargs.get('id')

        self.version = kwargs.get('version')

        self.component = kwargs.get('component', None)
        self.description = kwargs.get('description', None)
        self.metric = kwargs.get('metric', None)
        self.name = kwargs.get('name', None)
        self.tier_pricing = kwargs.get('tier_pricing', None)
        

    
    @property
    def id(self):
        """Gets the id of this ProductMeteredFeeUpdate.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this ProductMeteredFeeUpdate.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ProductMeteredFeeUpdate.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this ProductMeteredFeeUpdate.
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id
    
    @property
    def version(self):
        """Gets the version of this ProductMeteredFeeUpdate.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this ProductMeteredFeeUpdate.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ProductMeteredFeeUpdate.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this ProductMeteredFeeUpdate.
        :type: int
        """
        if version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")

        self._version = version
    
    @property
    def component(self):
        """Gets the component of this ProductMeteredFeeUpdate.

            

        :return: The component of this ProductMeteredFeeUpdate.
        :rtype: int
        """
        return self._component

    @component.setter
    def component(self, component):
        """Sets the component of this ProductMeteredFeeUpdate.

            

        :param component: The component of this ProductMeteredFeeUpdate.
        :type: int
        """

        self._component = component
    
    @property
    def description(self):
        """Gets the description of this ProductMeteredFeeUpdate.

            The description of a component fee describes the fee to the subscriber. The description may be shown in documents or on certain user interfaces.

        :return: The description of this ProductMeteredFeeUpdate.
        :rtype: dict(str, str)
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ProductMeteredFeeUpdate.

            The description of a component fee describes the fee to the subscriber. The description may be shown in documents or on certain user interfaces.

        :param description: The description of this ProductMeteredFeeUpdate.
        :type: dict(str, str)
        """

        self._description = description
    
    @property
    def metric(self):
        """Gets the metric of this ProductMeteredFeeUpdate.

            

        :return: The metric of this ProductMeteredFeeUpdate.
        :rtype: int
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """Sets the metric of this ProductMeteredFeeUpdate.

            

        :param metric: The metric of this ProductMeteredFeeUpdate.
        :type: int
        """

        self._metric = metric
    
    @property
    def name(self):
        """Gets the name of this ProductMeteredFeeUpdate.

            The name of the fee should describe for the subscriber in few words for what the fee is for.

        :return: The name of this ProductMeteredFeeUpdate.
        :rtype: dict(str, str)
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ProductMeteredFeeUpdate.

            The name of the fee should describe for the subscriber in few words for what the fee is for.

        :param name: The name of this ProductMeteredFeeUpdate.
        :type: dict(str, str)
        """

        self._name = name
    
    @property
    def tier_pricing(self):
        """Gets the tier_pricing of this ProductMeteredFeeUpdate.

            The tier pricing determines the calculation method of the tiers. The prices of the different tiers can be applied in different ways. The tier pricing controls this calculation.

        :return: The tier_pricing of this ProductMeteredFeeUpdate.
        :rtype: ProductMeteredTierPricing
        """
        return self._tier_pricing

    @tier_pricing.setter
    def tier_pricing(self, tier_pricing):
        """Sets the tier_pricing of this ProductMeteredFeeUpdate.

            The tier pricing determines the calculation method of the tiers. The prices of the different tiers can be applied in different ways. The tier pricing controls this calculation.

        :param tier_pricing: The tier_pricing of this ProductMeteredFeeUpdate.
        :type: ProductMeteredTierPricing
        """

        self._tier_pricing = tier_pricing
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ProductMeteredFeeUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ProductMeteredFeeUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class SubscriptionSuspensionReason(Enum):
    
    FAILED_CHARGE = "FAILED_CHARGE"
    SUBSCRIBER_INITIATED_REFUND = "SUBSCRIBER_INITIATED_REFUND"
    MANUAL = "MANUAL"




# coding: utf-8
import pprint
import six
from enum import Enum



class Role:

    swagger_types = {
    
        'account': 'Account',
        'id': 'int',
        'name': 'dict(str, str)',
        'permissions': 'list[Permission]',
        'planned_purge_date': 'datetime',
        'state': 'RoleState',
        'two_factor_required': 'bool',
        'version': 'int',
    }

    attribute_map = {
        'account': 'account','id': 'id','name': 'name','permissions': 'permissions','planned_purge_date': 'plannedPurgeDate','state': 'state','two_factor_required': 'twoFactorRequired','version': 'version',
    }

    
    _account = None
    _id = None
    _name = None
    _permissions = None
    _planned_purge_date = None
    _state = None
    _two_factor_required = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.account = kwargs.get('account', None)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.permissions = kwargs.get('permissions', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.state = kwargs.get('state', None)
        self.two_factor_required = kwargs.get('two_factor_required', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def account(self):
        """Gets the account of this Role.

            The account the role belongs to. The role can only be assigned within this account.

        :return: The account of this Role.
        :rtype: Account
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this Role.

            The account the role belongs to. The role can only be assigned within this account.

        :param account: The account of this Role.
        :type: Account
        """

        self._account = account
    
    @property
    def id(self):
        """Gets the id of this Role.

            A unique identifier for the object.

        :return: The id of this Role.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Role.

            A unique identifier for the object.

        :param id: The id of this Role.
        :type: int
        """

        self._id = id
    
    @property
    def name(self):
        """Gets the name of this Role.

            The name used to identify the role.

        :return: The name of this Role.
        :rtype: dict(str, str)
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Role.

            The name used to identify the role.

        :param name: The name of this Role.
        :type: dict(str, str)
        """

        self._name = name
    
    @property
    def permissions(self):
        """Gets the permissions of this Role.

            The permissions granted to users with this role.

        :return: The permissions of this Role.
        :rtype: list[Permission]
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this Role.

            The permissions granted to users with this role.

        :param permissions: The permissions of this Role.
        :type: list[Permission]
        """

        self._permissions = permissions
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this Role.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this Role.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this Role.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this Role.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def state(self):
        """Gets the state of this Role.

            The object's current state.

        :return: The state of this Role.
        :rtype: RoleState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Role.

            The object's current state.

        :param state: The state of this Role.
        :type: RoleState
        """

        self._state = state
    
    @property
    def two_factor_required(self):
        """Gets the two_factor_required of this Role.

            Whether users with this role are required to use two-factor authentication.

        :return: The two_factor_required of this Role.
        :rtype: bool
        """
        return self._two_factor_required

    @two_factor_required.setter
    def two_factor_required(self, two_factor_required):
        """Sets the two_factor_required of this Role.

            Whether users with this role are required to use two-factor authentication.

        :param two_factor_required: The two_factor_required of this Role.
        :type: bool
        """

        self._two_factor_required = two_factor_required
    
    @property
    def version(self):
        """Gets the version of this Role.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this Role.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Role.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this Role.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(Role, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, Role):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentMethodConfiguration:

    swagger_types = {
    
        'data_collection_type': 'DataCollectionType',
        'description': 'dict(str, str)',
        'id': 'int',
        'image_resource_path': 'ResourcePath',
        'linked_space_id': 'int',
        'name': 'str',
        'one_click_payment_mode': 'OneClickPaymentMode',
        'payment_method': 'int',
        'planned_purge_date': 'datetime',
        'resolved_description': 'dict(str, str)',
        'resolved_image_url': 'str',
        'resolved_title': 'dict(str, str)',
        'sort_order': 'int',
        'space_id': 'int',
        'state': 'CreationEntityState',
        'title': 'dict(str, str)',
        'version': 'int',
    }

    attribute_map = {
        'data_collection_type': 'dataCollectionType','description': 'description','id': 'id','image_resource_path': 'imageResourcePath','linked_space_id': 'linkedSpaceId','name': 'name','one_click_payment_mode': 'oneClickPaymentMode','payment_method': 'paymentMethod','planned_purge_date': 'plannedPurgeDate','resolved_description': 'resolvedDescription','resolved_image_url': 'resolvedImageUrl','resolved_title': 'resolvedTitle','sort_order': 'sortOrder','space_id': 'spaceId','state': 'state','title': 'title','version': 'version',
    }

    
    _data_collection_type = None
    _description = None
    _id = None
    _image_resource_path = None
    _linked_space_id = None
    _name = None
    _one_click_payment_mode = None
    _payment_method = None
    _planned_purge_date = None
    _resolved_description = None
    _resolved_image_url = None
    _resolved_title = None
    _sort_order = None
    _space_id = None
    _state = None
    _title = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.data_collection_type = kwargs.get('data_collection_type', None)
        self.description = kwargs.get('description', None)
        self.id = kwargs.get('id', None)
        self.image_resource_path = kwargs.get('image_resource_path', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.name = kwargs.get('name', None)
        self.one_click_payment_mode = kwargs.get('one_click_payment_mode', None)
        self.payment_method = kwargs.get('payment_method', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.resolved_description = kwargs.get('resolved_description', None)
        self.resolved_image_url = kwargs.get('resolved_image_url', None)
        self.resolved_title = kwargs.get('resolved_title', None)
        self.sort_order = kwargs.get('sort_order', None)
        self.space_id = kwargs.get('space_id', None)
        self.state = kwargs.get('state', None)
        self.title = kwargs.get('title', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def data_collection_type(self):
        """Gets the data_collection_type of this PaymentMethodConfiguration.

            The data collection type determines who is collecting the payment information. This can be done either by the processor (offsite) or by our application (onsite).

        :return: The data_collection_type of this PaymentMethodConfiguration.
        :rtype: DataCollectionType
        """
        return self._data_collection_type

    @data_collection_type.setter
    def data_collection_type(self, data_collection_type):
        """Sets the data_collection_type of this PaymentMethodConfiguration.

            The data collection type determines who is collecting the payment information. This can be done either by the processor (offsite) or by our application (onsite).

        :param data_collection_type: The data_collection_type of this PaymentMethodConfiguration.
        :type: DataCollectionType
        """

        self._data_collection_type = data_collection_type
    
    @property
    def description(self):
        """Gets the description of this PaymentMethodConfiguration.

            The payment method configuration description can be used to show a text during the payment process. Choose an appropriate description as it will be displayed to your customer.

        :return: The description of this PaymentMethodConfiguration.
        :rtype: dict(str, str)
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PaymentMethodConfiguration.

            The payment method configuration description can be used to show a text during the payment process. Choose an appropriate description as it will be displayed to your customer.

        :param description: The description of this PaymentMethodConfiguration.
        :type: dict(str, str)
        """

        self._description = description
    
    @property
    def id(self):
        """Gets the id of this PaymentMethodConfiguration.

            A unique identifier for the object.

        :return: The id of this PaymentMethodConfiguration.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentMethodConfiguration.

            A unique identifier for the object.

        :param id: The id of this PaymentMethodConfiguration.
        :type: int
        """

        self._id = id
    
    @property
    def image_resource_path(self):
        """Gets the image_resource_path of this PaymentMethodConfiguration.

            The image of the payment method configuration overrides the default image of the payment method.

        :return: The image_resource_path of this PaymentMethodConfiguration.
        :rtype: ResourcePath
        """
        return self._image_resource_path

    @image_resource_path.setter
    def image_resource_path(self, image_resource_path):
        """Sets the image_resource_path of this PaymentMethodConfiguration.

            The image of the payment method configuration overrides the default image of the payment method.

        :param image_resource_path: The image_resource_path of this PaymentMethodConfiguration.
        :type: ResourcePath
        """

        self._image_resource_path = image_resource_path
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this PaymentMethodConfiguration.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this PaymentMethodConfiguration.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this PaymentMethodConfiguration.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this PaymentMethodConfiguration.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def name(self):
        """Gets the name of this PaymentMethodConfiguration.

            The payment method configuration name is used internally to identify the payment method configuration. For example the name is used within search fields and hence it should be distinct and descriptive.

        :return: The name of this PaymentMethodConfiguration.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PaymentMethodConfiguration.

            The payment method configuration name is used internally to identify the payment method configuration. For example the name is used within search fields and hence it should be distinct and descriptive.

        :param name: The name of this PaymentMethodConfiguration.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def one_click_payment_mode(self):
        """Gets the one_click_payment_mode of this PaymentMethodConfiguration.

            When the buyer is present on the payment page or within the iFrame the payment details can be stored automatically. The buyer will be able to use the stored payment details for subsequent transactions. When the transaction already contains a token one-click payments are disabled anyway

        :return: The one_click_payment_mode of this PaymentMethodConfiguration.
        :rtype: OneClickPaymentMode
        """
        return self._one_click_payment_mode

    @one_click_payment_mode.setter
    def one_click_payment_mode(self, one_click_payment_mode):
        """Sets the one_click_payment_mode of this PaymentMethodConfiguration.

            When the buyer is present on the payment page or within the iFrame the payment details can be stored automatically. The buyer will be able to use the stored payment details for subsequent transactions. When the transaction already contains a token one-click payments are disabled anyway

        :param one_click_payment_mode: The one_click_payment_mode of this PaymentMethodConfiguration.
        :type: OneClickPaymentMode
        """

        self._one_click_payment_mode = one_click_payment_mode
    
    @property
    def payment_method(self):
        """Gets the payment_method of this PaymentMethodConfiguration.

            

        :return: The payment_method of this PaymentMethodConfiguration.
        :rtype: int
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this PaymentMethodConfiguration.

            

        :param payment_method: The payment_method of this PaymentMethodConfiguration.
        :type: int
        """

        self._payment_method = payment_method
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this PaymentMethodConfiguration.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this PaymentMethodConfiguration.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this PaymentMethodConfiguration.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this PaymentMethodConfiguration.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def resolved_description(self):
        """Gets the resolved_description of this PaymentMethodConfiguration.

            The resolved description uses the specified description or the default one when it is not overridden.

        :return: The resolved_description of this PaymentMethodConfiguration.
        :rtype: dict(str, str)
        """
        return self._resolved_description

    @resolved_description.setter
    def resolved_description(self, resolved_description):
        """Sets the resolved_description of this PaymentMethodConfiguration.

            The resolved description uses the specified description or the default one when it is not overridden.

        :param resolved_description: The resolved_description of this PaymentMethodConfiguration.
        :type: dict(str, str)
        """

        self._resolved_description = resolved_description
    
    @property
    def resolved_image_url(self):
        """Gets the resolved_image_url of this PaymentMethodConfiguration.

            The resolved URL of the image to use with this payment method.

        :return: The resolved_image_url of this PaymentMethodConfiguration.
        :rtype: str
        """
        return self._resolved_image_url

    @resolved_image_url.setter
    def resolved_image_url(self, resolved_image_url):
        """Sets the resolved_image_url of this PaymentMethodConfiguration.

            The resolved URL of the image to use with this payment method.

        :param resolved_image_url: The resolved_image_url of this PaymentMethodConfiguration.
        :type: str
        """

        self._resolved_image_url = resolved_image_url
    
    @property
    def resolved_title(self):
        """Gets the resolved_title of this PaymentMethodConfiguration.

            The resolved title uses the specified title or the default one when it is not overridden.

        :return: The resolved_title of this PaymentMethodConfiguration.
        :rtype: dict(str, str)
        """
        return self._resolved_title

    @resolved_title.setter
    def resolved_title(self, resolved_title):
        """Sets the resolved_title of this PaymentMethodConfiguration.

            The resolved title uses the specified title or the default one when it is not overridden.

        :param resolved_title: The resolved_title of this PaymentMethodConfiguration.
        :type: dict(str, str)
        """

        self._resolved_title = resolved_title
    
    @property
    def sort_order(self):
        """Gets the sort_order of this PaymentMethodConfiguration.

            The sort order of the payment method determines the ordering of the methods shown to the user during the payment process.

        :return: The sort_order of this PaymentMethodConfiguration.
        :rtype: int
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this PaymentMethodConfiguration.

            The sort order of the payment method determines the ordering of the methods shown to the user during the payment process.

        :param sort_order: The sort_order of this PaymentMethodConfiguration.
        :type: int
        """

        self._sort_order = sort_order
    
    @property
    def space_id(self):
        """Gets the space_id of this PaymentMethodConfiguration.

            

        :return: The space_id of this PaymentMethodConfiguration.
        :rtype: int
        """
        return self._space_id

    @space_id.setter
    def space_id(self, space_id):
        """Sets the space_id of this PaymentMethodConfiguration.

            

        :param space_id: The space_id of this PaymentMethodConfiguration.
        :type: int
        """

        self._space_id = space_id
    
    @property
    def state(self):
        """Gets the state of this PaymentMethodConfiguration.

            The object's current state.

        :return: The state of this PaymentMethodConfiguration.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PaymentMethodConfiguration.

            The object's current state.

        :param state: The state of this PaymentMethodConfiguration.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def title(self):
        """Gets the title of this PaymentMethodConfiguration.

            The title of the payment method configuration is used within the payment process. The title is visible to the customer.

        :return: The title of this PaymentMethodConfiguration.
        :rtype: dict(str, str)
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this PaymentMethodConfiguration.

            The title of the payment method configuration is used within the payment process. The title is visible to the customer.

        :param title: The title of this PaymentMethodConfiguration.
        :type: dict(str, str)
        """

        self._title = title
    
    @property
    def version(self):
        """Gets the version of this PaymentMethodConfiguration.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this PaymentMethodConfiguration.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PaymentMethodConfiguration.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this PaymentMethodConfiguration.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentMethodConfiguration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentMethodConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class InstallmentPlanSliceConfiguration:

    swagger_types = {
    
        'id': 'int',
        'line_item_title': 'dict(str, str)',
        'linked_space_id': 'int',
        'period': 'str',
        'plan': 'InstallmentPlanConfiguration',
        'planned_purge_date': 'datetime',
        'priority': 'int',
        'proportion': 'float',
        'state': 'CreationEntityState',
        'version': 'int',
    }

    attribute_map = {
        'id': 'id','line_item_title': 'lineItemTitle','linked_space_id': 'linkedSpaceId','period': 'period','plan': 'plan','planned_purge_date': 'plannedPurgeDate','priority': 'priority','proportion': 'proportion','state': 'state','version': 'version',
    }

    
    _id = None
    _line_item_title = None
    _linked_space_id = None
    _period = None
    _plan = None
    _planned_purge_date = None
    _priority = None
    _proportion = None
    _state = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.id = kwargs.get('id', None)
        self.line_item_title = kwargs.get('line_item_title', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.period = kwargs.get('period', None)
        self.plan = kwargs.get('plan', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.priority = kwargs.get('priority', None)
        self.proportion = kwargs.get('proportion', None)
        self.state = kwargs.get('state', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def id(self):
        """Gets the id of this InstallmentPlanSliceConfiguration.

            A unique identifier for the object.

        :return: The id of this InstallmentPlanSliceConfiguration.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InstallmentPlanSliceConfiguration.

            A unique identifier for the object.

        :param id: The id of this InstallmentPlanSliceConfiguration.
        :type: int
        """

        self._id = id
    
    @property
    def line_item_title(self):
        """Gets the line_item_title of this InstallmentPlanSliceConfiguration.

            The title of this slices line items. The title is visible to the buyer.

        :return: The line_item_title of this InstallmentPlanSliceConfiguration.
        :rtype: dict(str, str)
        """
        return self._line_item_title

    @line_item_title.setter
    def line_item_title(self, line_item_title):
        """Sets the line_item_title of this InstallmentPlanSliceConfiguration.

            The title of this slices line items. The title is visible to the buyer.

        :param line_item_title: The line_item_title of this InstallmentPlanSliceConfiguration.
        :type: dict(str, str)
        """

        self._line_item_title = line_item_title
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this InstallmentPlanSliceConfiguration.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this InstallmentPlanSliceConfiguration.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this InstallmentPlanSliceConfiguration.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this InstallmentPlanSliceConfiguration.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def period(self):
        """Gets the period of this InstallmentPlanSliceConfiguration.

            The period defines how much time passes between the last slice and this slice. The charge is triggered at the end of the period. When the slice should be charged immediately the period needs to be zero.

        :return: The period of this InstallmentPlanSliceConfiguration.
        :rtype: str
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this InstallmentPlanSliceConfiguration.

            The period defines how much time passes between the last slice and this slice. The charge is triggered at the end of the period. When the slice should be charged immediately the period needs to be zero.

        :param period: The period of this InstallmentPlanSliceConfiguration.
        :type: str
        """

        self._period = period
    
    @property
    def plan(self):
        """Gets the plan of this InstallmentPlanSliceConfiguration.

            The installment plan this slice belongs to.

        :return: The plan of this InstallmentPlanSliceConfiguration.
        :rtype: InstallmentPlanConfiguration
        """
        return self._plan

    @plan.setter
    def plan(self, plan):
        """Sets the plan of this InstallmentPlanSliceConfiguration.

            The installment plan this slice belongs to.

        :param plan: The plan of this InstallmentPlanSliceConfiguration.
        :type: InstallmentPlanConfiguration
        """

        self._plan = plan
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this InstallmentPlanSliceConfiguration.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this InstallmentPlanSliceConfiguration.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this InstallmentPlanSliceConfiguration.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this InstallmentPlanSliceConfiguration.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def priority(self):
        """Gets the priority of this InstallmentPlanSliceConfiguration.

            The priority controls in which order the slices are applied. The lower the value the higher the precedence.

        :return: The priority of this InstallmentPlanSliceConfiguration.
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this InstallmentPlanSliceConfiguration.

            The priority controls in which order the slices are applied. The lower the value the higher the precedence.

        :param priority: The priority of this InstallmentPlanSliceConfiguration.
        :type: int
        """

        self._priority = priority
    
    @property
    def proportion(self):
        """Gets the proportion of this InstallmentPlanSliceConfiguration.

            The proportion defines how much of the total installment payment has to be paid in this slice. The value is summed up with the other slices and the ratio of all proportions compared to proportion of this slice determines how much the buyer has to pay in this slice.

        :return: The proportion of this InstallmentPlanSliceConfiguration.
        :rtype: float
        """
        return self._proportion

    @proportion.setter
    def proportion(self, proportion):
        """Sets the proportion of this InstallmentPlanSliceConfiguration.

            The proportion defines how much of the total installment payment has to be paid in this slice. The value is summed up with the other slices and the ratio of all proportions compared to proportion of this slice determines how much the buyer has to pay in this slice.

        :param proportion: The proportion of this InstallmentPlanSliceConfiguration.
        :type: float
        """

        self._proportion = proportion
    
    @property
    def state(self):
        """Gets the state of this InstallmentPlanSliceConfiguration.

            The object's current state.

        :return: The state of this InstallmentPlanSliceConfiguration.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this InstallmentPlanSliceConfiguration.

            The object's current state.

        :param state: The state of this InstallmentPlanSliceConfiguration.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def version(self):
        """Gets the version of this InstallmentPlanSliceConfiguration.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this InstallmentPlanSliceConfiguration.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this InstallmentPlanSliceConfiguration.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this InstallmentPlanSliceConfiguration.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(InstallmentPlanSliceConfiguration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, InstallmentPlanSliceConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class DeliveryIndicationState(Enum):
    
    PENDING = "PENDING"
    NOT_SUITABLE = "NOT_SUITABLE"
    MANUAL_CHECK_REQUIRED = "MANUAL_CHECK_REQUIRED"
    SUITABLE = "SUITABLE"




# coding: utf-8
import pprint
import six
from enum import Enum



class AbstractDebtCollectionCaseUpdate:

    swagger_types = {
    
        'billing_address': 'AddressCreate',
        'contract_date': 'datetime',
        'currency': 'str',
        'due_date': 'datetime',
        'environment': 'DebtCollectionEnvironment',
        'language': 'str',
        'line_items': 'list[LineItemCreate]',
        'space_view_id': 'int',
    }

    attribute_map = {
        'billing_address': 'billingAddress','contract_date': 'contractDate','currency': 'currency','due_date': 'dueDate','environment': 'environment','language': 'language','line_items': 'lineItems','space_view_id': 'spaceViewId',
    }

    
    _billing_address = None
    _contract_date = None
    _currency = None
    _due_date = None
    _environment = None
    _language = None
    _line_items = None
    _space_view_id = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.billing_address = kwargs.get('billing_address', None)
        self.contract_date = kwargs.get('contract_date', None)
        self.currency = kwargs.get('currency', None)
        self.due_date = kwargs.get('due_date', None)
        self.environment = kwargs.get('environment', None)
        self.language = kwargs.get('language', None)
        self.line_items = kwargs.get('line_items', None)
        self.space_view_id = kwargs.get('space_view_id', None)
        

    
    @property
    def billing_address(self):
        """Gets the billing_address of this AbstractDebtCollectionCaseUpdate.

            The billing address of the case identifies the debtor.

        :return: The billing_address of this AbstractDebtCollectionCaseUpdate.
        :rtype: AddressCreate
        """
        return self._billing_address

    @billing_address.setter
    def billing_address(self, billing_address):
        """Sets the billing_address of this AbstractDebtCollectionCaseUpdate.

            The billing address of the case identifies the debtor.

        :param billing_address: The billing_address of this AbstractDebtCollectionCaseUpdate.
        :type: AddressCreate
        """

        self._billing_address = billing_address
    
    @property
    def contract_date(self):
        """Gets the contract_date of this AbstractDebtCollectionCaseUpdate.

            The contract date is the date on which the contract with the debtor was signed on.

        :return: The contract_date of this AbstractDebtCollectionCaseUpdate.
        :rtype: datetime
        """
        return self._contract_date

    @contract_date.setter
    def contract_date(self, contract_date):
        """Sets the contract_date of this AbstractDebtCollectionCaseUpdate.

            The contract date is the date on which the contract with the debtor was signed on.

        :param contract_date: The contract_date of this AbstractDebtCollectionCaseUpdate.
        :type: datetime
        """

        self._contract_date = contract_date
    
    @property
    def currency(self):
        """Gets the currency of this AbstractDebtCollectionCaseUpdate.

            The currency defines the billing currency of the debt collection case.

        :return: The currency of this AbstractDebtCollectionCaseUpdate.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this AbstractDebtCollectionCaseUpdate.

            The currency defines the billing currency of the debt collection case.

        :param currency: The currency of this AbstractDebtCollectionCaseUpdate.
        :type: str
        """

        self._currency = currency
    
    @property
    def due_date(self):
        """Gets the due_date of this AbstractDebtCollectionCaseUpdate.

            The due date indicates the date on which the amount receivable was due. This date has to be always in the past.

        :return: The due_date of this AbstractDebtCollectionCaseUpdate.
        :rtype: datetime
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this AbstractDebtCollectionCaseUpdate.

            The due date indicates the date on which the amount receivable was due. This date has to be always in the past.

        :param due_date: The due_date of this AbstractDebtCollectionCaseUpdate.
        :type: datetime
        """

        self._due_date = due_date
    
    @property
    def environment(self):
        """Gets the environment of this AbstractDebtCollectionCaseUpdate.

            The environment in which this case will be processed. There must be a debt collector configuration present which supports the chosen environment.

        :return: The environment of this AbstractDebtCollectionCaseUpdate.
        :rtype: DebtCollectionEnvironment
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """Sets the environment of this AbstractDebtCollectionCaseUpdate.

            The environment in which this case will be processed. There must be a debt collector configuration present which supports the chosen environment.

        :param environment: The environment of this AbstractDebtCollectionCaseUpdate.
        :type: DebtCollectionEnvironment
        """

        self._environment = environment
    
    @property
    def language(self):
        """Gets the language of this AbstractDebtCollectionCaseUpdate.

            The language indicates the language to be used in the communication with the debtor.

        :return: The language of this AbstractDebtCollectionCaseUpdate.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this AbstractDebtCollectionCaseUpdate.

            The language indicates the language to be used in the communication with the debtor.

        :param language: The language of this AbstractDebtCollectionCaseUpdate.
        :type: str
        """

        self._language = language
    
    @property
    def line_items(self):
        """Gets the line_items of this AbstractDebtCollectionCaseUpdate.

            The line items of the debt collection case will be shown on documents sent to the debtor and the total of them makes up total amount to collect.

        :return: The line_items of this AbstractDebtCollectionCaseUpdate.
        :rtype: list[LineItemCreate]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this AbstractDebtCollectionCaseUpdate.

            The line items of the debt collection case will be shown on documents sent to the debtor and the total of them makes up total amount to collect.

        :param line_items: The line_items of this AbstractDebtCollectionCaseUpdate.
        :type: list[LineItemCreate]
        """

        self._line_items = line_items
    
    @property
    def space_view_id(self):
        """Gets the space_view_id of this AbstractDebtCollectionCaseUpdate.

            

        :return: The space_view_id of this AbstractDebtCollectionCaseUpdate.
        :rtype: int
        """
        return self._space_view_id

    @space_view_id.setter
    def space_view_id(self, space_view_id):
        """Sets the space_view_id of this AbstractDebtCollectionCaseUpdate.

            

        :param space_view_id: The space_view_id of this AbstractDebtCollectionCaseUpdate.
        :type: int
        """

        self._space_view_id = space_view_id
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AbstractDebtCollectionCaseUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AbstractDebtCollectionCaseUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class SubscriptionProductRetirementCreate:

    swagger_types = {
    
        'product': 'int',
        'respect_terminiation_periods_enabled': 'bool',
        'target_product': 'int',
    }

    attribute_map = {
        'product': 'product','respect_terminiation_periods_enabled': 'respectTerminiationPeriodsEnabled','target_product': 'targetProduct',
    }

    
    _product = None
    _respect_terminiation_periods_enabled = None
    _target_product = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.product = kwargs.get('product')

        self.respect_terminiation_periods_enabled = kwargs.get('respect_terminiation_periods_enabled', None)
        self.target_product = kwargs.get('target_product', None)
        

    
    @property
    def product(self):
        """Gets the product of this SubscriptionProductRetirementCreate.

            

        :return: The product of this SubscriptionProductRetirementCreate.
        :rtype: int
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this SubscriptionProductRetirementCreate.

            

        :param product: The product of this SubscriptionProductRetirementCreate.
        :type: int
        """
        if product is None:
            raise ValueError("Invalid value for `product`, must not be `None`")

        self._product = product
    
    @property
    def respect_terminiation_periods_enabled(self):
        """Gets the respect_terminiation_periods_enabled of this SubscriptionProductRetirementCreate.

            

        :return: The respect_terminiation_periods_enabled of this SubscriptionProductRetirementCreate.
        :rtype: bool
        """
        return self._respect_terminiation_periods_enabled

    @respect_terminiation_periods_enabled.setter
    def respect_terminiation_periods_enabled(self, respect_terminiation_periods_enabled):
        """Sets the respect_terminiation_periods_enabled of this SubscriptionProductRetirementCreate.

            

        :param respect_terminiation_periods_enabled: The respect_terminiation_periods_enabled of this SubscriptionProductRetirementCreate.
        :type: bool
        """

        self._respect_terminiation_periods_enabled = respect_terminiation_periods_enabled
    
    @property
    def target_product(self):
        """Gets the target_product of this SubscriptionProductRetirementCreate.

            

        :return: The target_product of this SubscriptionProductRetirementCreate.
        :rtype: int
        """
        return self._target_product

    @target_product.setter
    def target_product(self, target_product):
        """Sets the target_product of this SubscriptionProductRetirementCreate.

            

        :param target_product: The target_product of this SubscriptionProductRetirementCreate.
        :type: int
        """

        self._target_product = target_product
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionProductRetirementCreate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionProductRetirementCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentAppVoidUpdateRequest:

    swagger_types = {
    
        'failure_reason_id': 'int',
        'reference': 'str',
        'target_state': 'PaymentAppVoidTargetState',
        'void_id': 'int',
    }

    attribute_map = {
        'failure_reason_id': 'failureReasonId','reference': 'reference','target_state': 'targetState','void_id': 'voidId',
    }

    
    _failure_reason_id = None
    _reference = None
    _target_state = None
    _void_id = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.failure_reason_id = kwargs.get('failure_reason_id', None)
        self.reference = kwargs.get('reference', None)
        self.target_state = kwargs.get('target_state', None)
        self.void_id = kwargs.get('void_id', None)
        

    
    @property
    def failure_reason_id(self):
        """Gets the failure_reason_id of this PaymentAppVoidUpdateRequest.

            The failure reason indicates why the void failed. It is required when the target state is FAILED.

        :return: The failure_reason_id of this PaymentAppVoidUpdateRequest.
        :rtype: int
        """
        return self._failure_reason_id

    @failure_reason_id.setter
    def failure_reason_id(self, failure_reason_id):
        """Sets the failure_reason_id of this PaymentAppVoidUpdateRequest.

            The failure reason indicates why the void failed. It is required when the target state is FAILED.

        :param failure_reason_id: The failure_reason_id of this PaymentAppVoidUpdateRequest.
        :type: int
        """

        self._failure_reason_id = failure_reason_id
    
    @property
    def reference(self):
        """Gets the reference of this PaymentAppVoidUpdateRequest.

            The reference identifies the void within the systems of the external service provider. It is required when the target state is SUCCESSFUL.

        :return: The reference of this PaymentAppVoidUpdateRequest.
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this PaymentAppVoidUpdateRequest.

            The reference identifies the void within the systems of the external service provider. It is required when the target state is SUCCESSFUL.

        :param reference: The reference of this PaymentAppVoidUpdateRequest.
        :type: str
        """
        if reference is not None and len(reference) > 100:
            raise ValueError("Invalid value for `reference`, length must be less than or equal to `100`")

        self._reference = reference
    
    @property
    def target_state(self):
        """Gets the target_state of this PaymentAppVoidUpdateRequest.

            The target state defines the state into which the void should be switched into. Once the void changed the state it will not be possible to change it again.

        :return: The target_state of this PaymentAppVoidUpdateRequest.
        :rtype: PaymentAppVoidTargetState
        """
        return self._target_state

    @target_state.setter
    def target_state(self, target_state):
        """Sets the target_state of this PaymentAppVoidUpdateRequest.

            The target state defines the state into which the void should be switched into. Once the void changed the state it will not be possible to change it again.

        :param target_state: The target_state of this PaymentAppVoidUpdateRequest.
        :type: PaymentAppVoidTargetState
        """

        self._target_state = target_state
    
    @property
    def void_id(self):
        """Gets the void_id of this PaymentAppVoidUpdateRequest.

            This is the ID of the void that should be updated.

        :return: The void_id of this PaymentAppVoidUpdateRequest.
        :rtype: int
        """
        return self._void_id

    @void_id.setter
    def void_id(self, void_id):
        """Sets the void_id of this PaymentAppVoidUpdateRequest.

            This is the ID of the void that should be updated.

        :param void_id: The void_id of this PaymentAppVoidUpdateRequest.
        :type: int
        """

        self._void_id = void_id
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentAppVoidUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentAppVoidUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class EntityQuery:

    swagger_types = {
    
        'filter': 'EntityQueryFilter',
        'language': 'str',
        'number_of_entities': 'int',
        'order_bys': 'list[EntityQueryOrderBy]',
        'starting_entity': 'int',
    }

    attribute_map = {
        'filter': 'filter','language': 'language','number_of_entities': 'numberOfEntities','order_bys': 'orderBys','starting_entity': 'startingEntity',
    }

    
    _filter = None
    _language = None
    _number_of_entities = None
    _order_bys = None
    _starting_entity = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.filter = kwargs.get('filter', None)
        self.language = kwargs.get('language', None)
        self.number_of_entities = kwargs.get('number_of_entities', None)
        self.order_bys = kwargs.get('order_bys', None)
        self.starting_entity = kwargs.get('starting_entity', None)
        

    
    @property
    def filter(self):
        """Gets the filter of this EntityQuery.

            The filter node defines the root filter node of the query. The root node may contain multiple sub nodes with different filters in it.

        :return: The filter of this EntityQuery.
        :rtype: EntityQueryFilter
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """Sets the filter of this EntityQuery.

            The filter node defines the root filter node of the query. The root node may contain multiple sub nodes with different filters in it.

        :param filter: The filter of this EntityQuery.
        :type: EntityQueryFilter
        """

        self._filter = filter
    
    @property
    def language(self):
        """Gets the language of this EntityQuery.

            The language is applied to the ordering of the entities returned. Some entity fields are language dependent and hence the language is required to order them.

        :return: The language of this EntityQuery.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this EntityQuery.

            The language is applied to the ordering of the entities returned. Some entity fields are language dependent and hence the language is required to order them.

        :param language: The language of this EntityQuery.
        :type: str
        """

        self._language = language
    
    @property
    def number_of_entities(self):
        """Gets the number_of_entities of this EntityQuery.

            The number of entities defines how many entities should be returned. There is a maximum of 100 entities.

        :return: The number_of_entities of this EntityQuery.
        :rtype: int
        """
        return self._number_of_entities

    @number_of_entities.setter
    def number_of_entities(self, number_of_entities):
        """Sets the number_of_entities of this EntityQuery.

            The number of entities defines how many entities should be returned. There is a maximum of 100 entities.

        :param number_of_entities: The number_of_entities of this EntityQuery.
        :type: int
        """

        self._number_of_entities = number_of_entities
    
    @property
    def order_bys(self):
        """Gets the order_bys of this EntityQuery.

            The order bys allows to define the ordering of the entities returned by the search.

        :return: The order_bys of this EntityQuery.
        :rtype: list[EntityQueryOrderBy]
        """
        return self._order_bys

    @order_bys.setter
    def order_bys(self, order_bys):
        """Sets the order_bys of this EntityQuery.

            The order bys allows to define the ordering of the entities returned by the search.

        :param order_bys: The order_bys of this EntityQuery.
        :type: list[EntityQueryOrderBy]
        """

        self._order_bys = order_bys
    
    @property
    def starting_entity(self):
        """Gets the starting_entity of this EntityQuery.

            The 'starting entity' defines the entity number at which the returned result should start. The entity number is the consecutive number of the entity as returned and it is not the entity id.

        :return: The starting_entity of this EntityQuery.
        :rtype: int
        """
        return self._starting_entity

    @starting_entity.setter
    def starting_entity(self, starting_entity):
        """Sets the starting_entity of this EntityQuery.

            The 'starting entity' defines the entity number at which the returned result should start. The entity number is the consecutive number of the entity as returned and it is not the entity id.

        :param starting_entity: The starting_entity of this EntityQuery.
        :type: int
        """

        self._starting_entity = starting_entity
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(EntityQuery, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, EntityQuery):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class ClientErrorType(Enum):
    
    END_USER_ERROR = "END_USER_ERROR"
    CONFIGURATION_ERROR = "CONFIGURATION_ERROR"
    DEVELOPER_ERROR = "DEVELOPER_ERROR"




# coding: utf-8
import pprint
import six
from enum import Enum



class RestCountry:

    swagger_types = {
    
        'address_format': 'RestAddressFormat',
        'iso_code2': 'str',
        'iso_code3': 'str',
        'name': 'str',
        'numeric_code': 'str',
        'state_codes': 'list[str]',
    }

    attribute_map = {
        'address_format': 'addressFormat','iso_code2': 'isoCode2','iso_code3': 'isoCode3','name': 'name','numeric_code': 'numericCode','state_codes': 'stateCodes',
    }

    
    _address_format = None
    _iso_code2 = None
    _iso_code3 = None
    _name = None
    _numeric_code = None
    _state_codes = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.address_format = kwargs.get('address_format', None)
        self.iso_code2 = kwargs.get('iso_code2', None)
        self.iso_code3 = kwargs.get('iso_code3', None)
        self.name = kwargs.get('name', None)
        self.numeric_code = kwargs.get('numeric_code', None)
        self.state_codes = kwargs.get('state_codes', None)
        

    
    @property
    def address_format(self):
        """Gets the address_format of this RestCountry.

            Specifies the country's way of formatting addresses.

        :return: The address_format of this RestCountry.
        :rtype: RestAddressFormat
        """
        return self._address_format

    @address_format.setter
    def address_format(self, address_format):
        """Sets the address_format of this RestCountry.

            Specifies the country's way of formatting addresses.

        :param address_format: The address_format of this RestCountry.
        :type: RestAddressFormat
        """

        self._address_format = address_format
    
    @property
    def iso_code2(self):
        """Gets the iso_code2 of this RestCountry.

            The country's two-letter code (ISO 3166-1 alpha-2 format).

        :return: The iso_code2 of this RestCountry.
        :rtype: str
        """
        return self._iso_code2

    @iso_code2.setter
    def iso_code2(self, iso_code2):
        """Sets the iso_code2 of this RestCountry.

            The country's two-letter code (ISO 3166-1 alpha-2 format).

        :param iso_code2: The iso_code2 of this RestCountry.
        :type: str
        """

        self._iso_code2 = iso_code2
    
    @property
    def iso_code3(self):
        """Gets the iso_code3 of this RestCountry.

            The country's three-letter code (ISO 3166-1 alpha-3 format).

        :return: The iso_code3 of this RestCountry.
        :rtype: str
        """
        return self._iso_code3

    @iso_code3.setter
    def iso_code3(self, iso_code3):
        """Sets the iso_code3 of this RestCountry.

            The country's three-letter code (ISO 3166-1 alpha-3 format).

        :param iso_code3: The iso_code3 of this RestCountry.
        :type: str
        """

        self._iso_code3 = iso_code3
    
    @property
    def name(self):
        """Gets the name of this RestCountry.

            The name of the country.

        :return: The name of this RestCountry.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RestCountry.

            The name of the country.

        :param name: The name of this RestCountry.
        :type: str
        """

        self._name = name
    
    @property
    def numeric_code(self):
        """Gets the numeric_code of this RestCountry.

            The country's three-digit code (ISO 3166-1 numeric format).

        :return: The numeric_code of this RestCountry.
        :rtype: str
        """
        return self._numeric_code

    @numeric_code.setter
    def numeric_code(self, numeric_code):
        """Sets the numeric_code of this RestCountry.

            The country's three-digit code (ISO 3166-1 numeric format).

        :param numeric_code: The numeric_code of this RestCountry.
        :type: str
        """

        self._numeric_code = numeric_code
    
    @property
    def state_codes(self):
        """Gets the state_codes of this RestCountry.

            The codes of all regions (e.g. states, provinces) of the country (ISO 3166-2 format).

        :return: The state_codes of this RestCountry.
        :rtype: list[str]
        """
        return self._state_codes

    @state_codes.setter
    def state_codes(self, state_codes):
        """Sets the state_codes of this RestCountry.

            The codes of all regions (e.g. states, provinces) of the country (ISO 3166-2 format).

        :param state_codes: The state_codes of this RestCountry.
        :type: list[str]
        """

        self._state_codes = state_codes
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(RestCountry, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, RestCountry):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class InstallmentCalculatedPlan:

    swagger_types = {
    
        'configuration': 'InstallmentPlanConfiguration',
        'payment_method_configurations': 'list[PaymentMethodConfiguration]',
        'slices': 'list[InstallmentCalculatedSlice]',
        'total_amount': 'float',
        'transaction': 'Transaction',
    }

    attribute_map = {
        'configuration': 'configuration','payment_method_configurations': 'paymentMethodConfigurations','slices': 'slices','total_amount': 'totalAmount','transaction': 'transaction',
    }

    
    _configuration = None
    _payment_method_configurations = None
    _slices = None
    _total_amount = None
    _transaction = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.configuration = kwargs.get('configuration', None)
        self.payment_method_configurations = kwargs.get('payment_method_configurations', None)
        self.slices = kwargs.get('slices', None)
        self.total_amount = kwargs.get('total_amount', None)
        self.transaction = kwargs.get('transaction', None)
        

    
    @property
    def configuration(self):
        """Gets the configuration of this InstallmentCalculatedPlan.

            

        :return: The configuration of this InstallmentCalculatedPlan.
        :rtype: InstallmentPlanConfiguration
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this InstallmentCalculatedPlan.

            

        :param configuration: The configuration of this InstallmentCalculatedPlan.
        :type: InstallmentPlanConfiguration
        """

        self._configuration = configuration
    
    @property
    def payment_method_configurations(self):
        """Gets the payment_method_configurations of this InstallmentCalculatedPlan.

            

        :return: The payment_method_configurations of this InstallmentCalculatedPlan.
        :rtype: list[PaymentMethodConfiguration]
        """
        return self._payment_method_configurations

    @payment_method_configurations.setter
    def payment_method_configurations(self, payment_method_configurations):
        """Sets the payment_method_configurations of this InstallmentCalculatedPlan.

            

        :param payment_method_configurations: The payment_method_configurations of this InstallmentCalculatedPlan.
        :type: list[PaymentMethodConfiguration]
        """

        self._payment_method_configurations = payment_method_configurations
    
    @property
    def slices(self):
        """Gets the slices of this InstallmentCalculatedPlan.

            

        :return: The slices of this InstallmentCalculatedPlan.
        :rtype: list[InstallmentCalculatedSlice]
        """
        return self._slices

    @slices.setter
    def slices(self, slices):
        """Sets the slices of this InstallmentCalculatedPlan.

            

        :param slices: The slices of this InstallmentCalculatedPlan.
        :type: list[InstallmentCalculatedSlice]
        """

        self._slices = slices
    
    @property
    def total_amount(self):
        """Gets the total_amount of this InstallmentCalculatedPlan.

            

        :return: The total_amount of this InstallmentCalculatedPlan.
        :rtype: float
        """
        return self._total_amount

    @total_amount.setter
    def total_amount(self, total_amount):
        """Sets the total_amount of this InstallmentCalculatedPlan.

            

        :param total_amount: The total_amount of this InstallmentCalculatedPlan.
        :type: float
        """

        self._total_amount = total_amount
    
    @property
    def transaction(self):
        """Gets the transaction of this InstallmentCalculatedPlan.

            

        :return: The transaction of this InstallmentCalculatedPlan.
        :rtype: Transaction
        """
        return self._transaction

    @transaction.setter
    def transaction(self, transaction):
        """Sets the transaction of this InstallmentCalculatedPlan.

            

        :param transaction: The transaction of this InstallmentCalculatedPlan.
        :type: Transaction
        """

        self._transaction = transaction
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(InstallmentCalculatedPlan, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, InstallmentCalculatedPlan):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
